@@ -1,5 +1,5 @@
 """ version which can be consumed from within the module """
-VERSION_STR = "0.1.60"
-DESCRIPTION = "pyawskit is a collection of utilities to help interact with aws"
+VERSION_STR = "0.1.73"
+DESCRIPTION = "Pyawskit is your AWS Swiss Army Knife"
 APP_NAME = "pyawskit"
 LOGGER_NAME = "pyawskit"
